var ipaddress = "";
var sessionId = "";
var pairingKey = "";
var retries = 0;
var contentHeader = { "Content-Type": "application/atom+xml" };

function getIPAddress() {
    var request = new NetworkRequest();
    request.url = "http://www.google.com";
    request.statusChanged.connect(function () { print("Status changed"); });
    request.get();
}

function checkIPAddress(response) {
    response = decodeURIComponent(response);
    print(response);

    if (response.search(/lg/i)) {
        ipaddress = response;
	ipLabel.text = "IP address: " + ipaddress;
        retries = 0;
        print("IP Address is " + ipaddress);
    }
    else if (retries < 5) {
        retries += 1;
        print("getIPAddress(): Retry " + retries);
        getIPAddress();
    }
    else {
        print("Cannot get IP address");
    }
}

function getPairingKey() {
    http.post(ipaddress + "/roap/api/auth", "AuthKeyReq", contentHeader);
}

function getSessionId() {
    http.post(ipaddress + "/roap/api/auth", "AuthReq" + pairingKey, contentHeader, "checkSessionId");
}

function checkSessionId(response) {
    sessionId = response.split("<session>")[1].split("<")[0];

    if (sessionId) {
	sessionLabel.text = "Session id: " + sessionId;
        print("Session id is " + sessionId);
    }
    else {
        print("Cannot get session id");
    }
}

function sendCommand(command) {
    http.post(ipaddress + "/roap/api/command", "HandleKeyInput" + command, contentHeader);
}
